@@ -73,6 +73,7 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         self.setupUi(self)
         self.setWindowIcon(appicon)
 
+        self.checkDBMaxDays.setEnabled(True)
         self.dbFileButton.setVisible(False)
         self.dbLabel.setVisible(False)
         self.dbType = None
@@ -87,6 +88,8 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         self.comboUITheme.currentIndexChanged.connect(self._cb_combo_themes_changed)
         self.cmdTimeoutUp.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinUITimeout, self.SUM))
         self.cmdTimeoutDown.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinUITimeout, self.REST))
+        self.cmdRefreshUIUp.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinUIRefresh, self.SUM))
+        self.cmdRefreshUIDown.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinUIRefresh, self.REST))
         self.cmdDBMaxDaysUp.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinDBMaxDays, self.SUM))
         self.cmdDBMaxDaysDown.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinDBMaxDays, self.REST))
         self.cmdDBPurgesUp.clicked.connect(lambda: self._cb_cmd_spin_clicked(self.spinDBPurgeInterval, self.SUM))
@@ -132,6 +135,8 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
 
         self.cmdTimeoutUp.setIcon(addIcon)
         self.cmdTimeoutDown.setIcon(delIcon)
+        self.cmdRefreshUIUp.setIcon(addIcon)
+        self.cmdRefreshUIDown.setIcon(delIcon)
         self.cmdDBMaxDaysUp.setIcon(addIcon)
         self.cmdDBMaxDaysDown.setIcon(delIcon)
         self.cmdDBPurgesUp.setIcon(addIcon)
@@ -259,6 +264,9 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         self.comboUIDuration.setCurrentIndex(self._default_duration)
         self.comboUIDialogPos.setCurrentIndex(self._cfg.getInt(self._cfg.DEFAULT_POPUP_POSITION))
 
+        self._ui_refresh_interval = self._cfg.getInt(self._cfg.STATS_REFRESH_INTERVAL, 0)
+        self.spinUIRefresh.setValue(self._ui_refresh_interval)
+
         self.checkAutostart.setChecked(self._autostart.isEnabled())
 
         maxmsgsize = self._cfg.getSettings(Config.DEFAULT_SERVER_MAX_MESSAGE_LENGTH)
@@ -518,7 +526,7 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
 
         if self.comboDBType.currentIndex() != Database.DB_TYPE_MEMORY:
             if self.dbLabel.text() != "":
-                self._cfg.setSettings(Config.DEFAULT_DB_FILE_KEY, self.dbLabel.text())
+                db_name = self.dbLabel.text()
             else:
                 Message.ok(
                     QC.translate("preferences", "Warning"),
@@ -526,7 +534,10 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
                     QtWidgets.QMessageBox.Warning)
                 self.dbLabel.setText("")
                 return False
+        else:
+            db_name = Database.DB_IN_MEMORY
 
+        self._cfg.setSettings(Config.DEFAULT_DB_FILE_KEY, db_name)
         self._cfg.setSettings(Config.DEFAULT_DB_TYPE_KEY, dbtype)
         self._cfg.setSettings(Config.DEFAULT_DB_PURGE_OLDEST, bool(self.checkDBMaxDays.isChecked()))
         self._cfg.setSettings(Config.DEFAULT_DB_MAX_DAYS, int(self.spinDBMaxDays.value()))
@@ -577,6 +588,7 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
             if self.checkUIRules.isChecked():
                 self._nodes.delete_rule_by_field(Config.DURATION_FIELD, Config.RULES_DURATION_FILTER)
 
+            self._cfg.setSettings(self._cfg.STATS_REFRESH_INTERVAL, int(self.spinUIRefresh.value()))
             self._cfg.setSettings(self._cfg.DEFAULT_ACTION_KEY, self.comboUIAction.currentIndex())
             self._cfg.setSettings(self._cfg.DEFAULT_DURATION_KEY, int(self.comboUIDuration.currentIndex()))
             self._cfg.setSettings(self._cfg.DEFAULT_TARGET_KEY, self.comboUITarget.currentIndex())
@@ -774,7 +786,6 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
 
     def _enable_db_cleaner_options(self, enable, db_max_days):
         self.checkDBMaxDays.setChecked(enable)
-        self.checkDBMaxDays.setEnabled(enable)
         self.spinDBMaxDays.setEnabled(enable)
         self.spinDBPurgeInterval.setEnabled(enable)
         self.labelDBPurgeInterval.setEnabled(enable)
@@ -825,8 +836,7 @@ class PreferencesDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         isDBMem = self.comboDBType.currentIndex() == Database.DB_TYPE_MEMORY
         self.dbFileButton.setVisible(not isDBMem)
         self.dbLabel.setVisible(not isDBMem)
-        self.checkDBMaxDays.setEnabled(not isDBMem)
-        self.checkDBMaxDays.setChecked(not isDBMem)
+        self.checkDBMaxDays.setChecked(self._cfg.getBool(Config.DEFAULT_DB_PURGE_OLDEST))
         self.checkDBJrnlWal.setEnabled(not isDBMem)
         self.checkDBJrnlWal.setChecked(False)
 
